# Roches Beach coastal hazard probabilistic assessment

## Workflow

#### 1. Open anaconda prompt.

Double-click `anaconda-prompt.bat`  
(All further commands should be entered into this prompt)

#### 2. Generate ZSA and ZRFC recession tables.

The package required to calculate setbacks based on Nielsen et al. (1992) can be found here:  
http://git.wrl.unsw.edu.au:3000/coastal/nielsen

```shell
  > cd lidar  
  > python generate_recession_tables.py
```

The setback chainages are saved here:

    lidar/
    ├── recession_results_zrfc.csv
    └── recession_results_zsa.csv

The profile cross-sections are plotted here:

    lidar/
    └── png
        ├── P1.png
        ├── P2.png
        └── ...

#### 3. Prepare input files

Update values in `adopted-input-values.xlsx`  
Generate `yaml` files:

```shell
  > cd ../inputs
  > python get_adopted_input_values.py
```

The `yaml` files are saved here:

    probabilistic-analysis/
    ├── Roches P1.yaml
    ├── Roches P2.yaml
    └── ...

#### 4. Run probabilistic simulation

```shell
  > cd ../probabilistic-analysis
  > python probabilistic_assessment.py
```

Chainage setbacks are saved in csv files, and diagnostics are saved in csv/png files here:

    probabilistic-analysis/
    └── output_csv
    │   ├── Roches P1 2022 ZRFC.csv
    │   ├── Roches P1 2022 ZSA.csv
    │   ├── Roches P1 2050 ZRFC.csv
    │   └── ...
    └── diagnostics
        ├── Roches P1 2022 ZRFC.csv
        ├── Roches P1 2022 ZSA.csv
        ├── Roches P1 ZRFC scatter.png
        ├── Roches P1 ZRFC timeseries.png
        └── ...

#### 5. Generate hazard line shapefile

```shell
  > cd ../probabilistic-analysis
  > python csv_to_shp.py
```

Shapefile is saved here:

    probabilistic-analysis/
    └── output_shp
        ├── hazard-lines.dbf
        ├── hazard-lines.prj
        └── hazard-lines.shp

#### 6. Export maps

```shell
  > cd ../qgis
  > export.bat
```
